@@ -1,13 +1,34 @@
+# #
+# This software was developed and / or modified by Raytheon Company,
+# pursuant to Contract DG133W-05-CQ-1067 with the US Government.
+#
+# U.S. EXPORT CONTROLLED TECHNICAL DATA
+# This software product contains export-restricted data whose
+# export/transfer/disclosure is restricted by U.S. law. Dissemination
+# to non-U.S. persons whether in the United States or abroad requires
+# an export license or other authorization.
+#
+# Contractor Name:        Raytheon Company
+# Contractor Address:     6825 Pine Street, Suite 340
+#                         Mail Stop B8
+#                         Omaha, NE 68106
+#                         402.291.0100
+#
+# See the AWIPS II Master Rights File ("Master Rights File.pdf") for
+# further licensing information.
+# #
+
 #
 # Published interface for retrieving data updates via awips.dataaccess package
 #
+# SOFTWARE HISTORY
 #
-#     SOFTWARE HISTORY
-#
-#    Date            Ticket#       Engineer       Description
-#    ------------    ----------    -----------    --------------------------
-#    May 26, 2016    2416          rjpeter        Initial Creation.
-#    Aug  1, 2016    2416          tgurney        Finish implementation
+# Date          Ticket#  Engineer     Description
+# ------------- -------- ------------ --------------------------------------------
+# May 26, 2016  2416     rjpeter      Initial Creation.
+# Aug 01, 2016  2416     tgurney      Finish implementation
+# Nov 05, 2019  7884     tgurney      Python 3 fixes
+# Jun 24, 2020  8187     randerso     Added program for qpid connection_id
 #
 #
 
@@ -39,25 +60,25 @@ each time a METAR is received from there.
   request = DAL.newDataRequest('obs')
   request.setParameters('temperature')
   request.setLocationNames('KOMA')
-
+  
   notifier = DNL.getGeometryDataUpdates(request)
   notifier.subscribe(process_obs)
   # process_obs will called with a list of data each time new data comes in
 
 """
 
-import re
 import sys
+import subprocess
 from awips.dataaccess.PyGeometryNotification import PyGeometryNotification
 from awips.dataaccess.PyGridNotification import PyGridNotification
 
 
-THRIFT_HOST = "edex"
+THRIFT_HOST = subprocess.check_output(
+                    "source /awips2/fxa/bin/setup.env; echo $DEFAULT_HOST",
+                    shell=True).decode().strip()
 
 USING_NATIVE_THRIFT = False
 
-JMS_HOST_PATTERN = re.compile('tcp://([^:]+):([0-9]+)')
-
 if 'jep' in sys.modules:
     # intentionally do not catch if this fails to import, we want it to
     # be obvious that something is configured wrong when running from within
@@ -73,9 +94,9 @@ else:
 def _getJmsConnectionInfo(notifFilterResponse):
     serverString = notifFilterResponse.getJmsConnectionInfo()
     try:
-        host, port = JMS_HOST_PATTERN.match(serverString).groups()
-    except AttributeError:
-        raise RuntimeError('Got bad JMS connection info from server: ' + serverString)
+        host, port = serverString.split(':')
+    except Exception as e:
+        raise ValueError('Got bad JMS connection info from server: "' + serverString + '"') from e
     return {'host': host, 'port': port}
 
 
@@ -91,10 +112,9 @@ def getGridDataUpdates(request):
             calling its subscribe() method
     """
     response = router.getNotificationFilter(request)
-    notificationFilter = response.getNotificationFilter()
+    filter = response.getNotificationFilter()
     jmsInfo = _getJmsConnectionInfo(response)
-    notifier = PyGridNotification(request, notificationFilter,
-                                  requestHost=THRIFT_HOST, **jmsInfo)
+    notifier = PyGridNotification(request, filter, requestHost=THRIFT_HOST, program="daf-gridDataUpdates", **jmsInfo)
     return notifier
 
 
@@ -110,10 +130,9 @@ def getGeometryDataUpdates(request):
             calling its subscribe() method
     """
     response = router.getNotificationFilter(request)
-    notificationFilter = response.getNotificationFilter()
+    filter = response.getNotificationFilter()
     jmsInfo = _getJmsConnectionInfo(response)
-    notifier = PyGeometryNotification(request, notificationFilter,
-                                      requestHost=THRIFT_HOST, **jmsInfo)
+    notifier = PyGeometryNotification(request, filter, requestHost=THRIFT_HOST, program="daf-geometryDataUpdates", **jmsInfo)
     return notifier
 
 
@@ -124,7 +143,7 @@ def changeEDEXHost(newHostName):
     method will throw a TypeError.
 
     Args:
-            newHostName: the EDEX host to connect to
+            newHostHame: the EDEX host to connect to
     """
     if USING_NATIVE_THRIFT:
         global THRIFT_HOST
