@@ -1,10 +1,30 @@
-from __future__ import print_function
+##
+# This software was developed and / or modified by Raytheon Company,
+# pursuant to Contract DG133W-05-CQ-1067 with the US Government.
+#
+# U.S. EXPORT CONTROLLED TECHNICAL DATA
+# This software product contains export-restricted data whose
+# export/transfer/disclosure is restricted by U.S. law. Dissemination
+# to non-U.S. persons whether in the United States or abroad requires
+# an export license or other authorization.
+#
+# Contractor Name:        Raytheon Company
+# Contractor Address:     6825 Pine Street, Suite 340
+#                         Mail Stop B8
+#                         Omaha, NE 68106
+#                         402.291.0100
+#
+# See the AWIPS II Master Rights File ("Master Rights File.pdf") for
+# further licensing information.
+##
+
+
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
 from awips.dataaccess import DataAccessLayer as DAL
 from awips.ThriftClient import ThriftRequestException
 
-from awips.test.dafTests import baseDafTestCase
-from awips.test.dafTests import params
+from . import baseDafTestCase
+from . import params
 
 #
 # Test DAF support for GFE edit area data
@@ -120,11 +140,6 @@ class GfeEditAreaTestCase(baseDafTestCase.DafTestCase):
         for record in geomData:
             self.assertEqual(record.getAttribute(self.siteIdKey), params.SITE_ID)
 
-    def testGetDataWithEqualsUnicode(self):
-        geomData = self._runConstraintTest(self.siteIdKey, '=', params.SITE_ID.decode('unicode-escape'))
-        for record in geomData:
-            self.assertEqual(record.getAttribute(self.siteIdKey), params.SITE_ID)
-
     # No numeric tests since no numeric identifiers are available.
 
     def testGetDataWithEqualsNone(self):
